Index: pkg/dartino_compiler/lib/src/dynamic_call_enqueuer.dart |
diff --git a/pkg/fletchc/lib/src/dynamic_call_enqueuer.dart b/pkg/dartino_compiler/lib/src/dynamic_call_enqueuer.dart |
similarity index 96% |
rename from pkg/fletchc/lib/src/dynamic_call_enqueuer.dart |
rename to pkg/dartino_compiler/lib/src/dynamic_call_enqueuer.dart |
index 99066c64581589f25f0cd6beb00206e1c6a77d49..fb643837ab67c84152dfe91856576178e1658475 100644 |
--- a/pkg/fletchc/lib/src/dynamic_call_enqueuer.dart |
+++ b/pkg/dartino_compiler/lib/src/dynamic_call_enqueuer.dart |
@@ -2,7 +2,7 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-library fletchc.dynamic_call_enqueuer; |
+library dartino_compiler.dynamic_call_enqueuer; |
import 'dart:collection' show |
Queue; |
@@ -33,13 +33,13 @@ import 'package:compiler/src/common/names.dart' show |
import 'package:compiler/src/util/util.dart' show |
Hashing; |
-import 'fletch_compiler_implementation.dart' show |
- FletchCompilerImplementation; |
+import 'dartino_compiler_implementation.dart' show |
+ DartinoCompilerImplementation; |
-import 'fletch_enqueuer.dart' show |
+import 'dartino_enqueuer.dart' show |
shouldReportEnqueuingOfElement; |
-import 'fletch_registry.dart' show |
+import 'dartino_registry.dart' show |
ClosureKind; |
abstract class UsageRecorder { |
@@ -55,7 +55,7 @@ abstract class UsageRecorder { |
/// By "dynamic" part we mean the part that is about matching instantiated |
/// classes with called instance methods. |
class DynamicCallEnqueuer { |
- final FletchCompilerImplementation compiler; |
+ final DartinoCompilerImplementation compiler; |
final Set<ClassElement> instantiatedClasses = new Set<ClassElement>(); |
@@ -234,7 +234,7 @@ class DynamicCallEnqueuer { |
revisitClass(cls); |
// Once we have found one class that implements [member], we're |
// done. When we later call [enqueueInstanceMethods] (via |
// [FletchEnqueuer.processQueue]) the method will be enqueued again |
// (if it exists). |
break; |
} |
@@ -234,7 +234,7 @@ class DynamicCallEnqueuer { |
// Once we have found one class that implements [member], we're |
// done. When we later call [enqueueInstanceMethods] (via |
- // [FletchEnqueuer.processQueue]) the method will be enqueued again |
+ // [DartinoEnqueuer.processQueue]) the method will be enqueued again |
// (if it exists). |
break; |